==> cargo-binstall-1.15.11-1.src.tar.gz: cargo-binstall-1.15.11/crates/binstalk-downloader/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.13.22](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.21...binstalk-downloader-v0.13.22) - 2025-08-30

### Other

- Upgrade compression libraries ([#2289](https://github.com/cargo-bins/cargo-binstall/pull/2289))

## [0.13.21](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.20...binstalk-downloader-v0.13.21) - 2025-07-25

### Other

- *(deps)* bump tokio from 1.46.0 to 1.46.1 in the deps group ([#2222](https://github.com/cargo-bins/cargo-binstall/pull/2222))
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.13.26](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.25...binstalk-downloader-v0.13.26) - 2025-11-09

### Other

- Update rc-zip-sync version to 4.3.5 ([#2362](https://github.com/cargo-bins/cargo-binstall/pull/2362))

## [0.13.25](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.24...binstalk-downloader-v0.13.25) - 2025-10-25

### Fixed

- fix CVE-2025-62518 ([#2340](https://github.com/cargo-bins/cargo-binstall/pull/2340))

### Other

- *(deps)* bump flate2 from 1.1.4 to 1.1.5 in the deps group ([#2342](https://github.com/cargo-bins/cargo-binstall/pull/2342))

## [0.13.24](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.23...binstalk-downloader-v0.13.24) - 2025-10-24

### Other

- *(lints)* introduce typos-cli config in `Cargo.toml` and handle typos ([#2337](https://github.com/cargo-bins/cargo-binstall/pull/2337))
- *(deps)* bump rc-zip-sync from 4.3.1 to 4.3.2 in the deps group ([#2334](https://github.com/cargo-bins/cargo-binstall/pull/2334))

## [0.13.23](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.22...binstalk-downloader-v0.13.23) - 2025-09-14

### Added

- respect socks5 in `https_proxy` ([#2306](https://github.com/cargo-bins/cargo-binstall/pull/2306))

## [0.13.20](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.19...binstalk-downloader-v0.13.20) - 2025-06-06

### Other

- updated the following local packages: binstalk-types

## [0.13.19](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.18...binstalk-downloader-v0.13.19) - 2025-05-30

### Other

- Upgrade reqwest to 0.12.17 ([#2168](https://github.com/cargo-bins/cargo-binstall/pull/2168))

## [0.13.18](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.17...binstalk-downloader-v0.13.18) - 2025-05-16

### Other

- Upgrade transitive dependencies ([#2154](https://github.com/cargo-bins/cargo-binstall/pull/2154))

## [0.13.17](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.16...binstalk-downloader-v0.13.17) - 2025-04-05

### Other

- Fix clippy lints ([#2111](https://github.com/cargo-bins/cargo-binstall/pull/2111))

## [0.13.16](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.15...binstalk-downloader-v0.13.16) - 2025-03-19

### Other

- Fix clippy warnings for detect-targets and binstalk-downloader ([#2098](https://github.com/cargo-bins/cargo-binstall/pull/2098))
- Bump hickory-resolver to 0.25.1 ([#2096](https://github.com/cargo-bins/cargo-binstall/pull/2096))

## [0.13.15](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.14...binstalk-downloader-v0.13.15) - 2025-03-15

### Other

- *(deps)* bump the deps group with 2 updates ([#2084](https://github.com/cargo-bins/cargo-binstall/pull/2084))
- *(deps)* bump tokio from 1.43.0 to 1.44.0 in the deps group ([#2079](https://github.com/cargo-bins/cargo-binstall/pull/2079))

## [0.13.14](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.13...binstalk-downloader-v0.13.14) - 2025-03-07

### Other

- Use bzip2/libbz2-rs-sys ([#2071](https://github.com/cargo-bins/cargo-binstall/pull/2071))
- *(deps)* bump the deps group with 3 updates ([#2072](https://github.com/cargo-bins/cargo-binstall/pull/2072))

## [0.13.13](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.12...binstalk-downloader-v0.13.13) - 2025-02-28

### Other

- Use flate2/zlib-rs for dev/release build ([#2068](https://github.com/cargo-bins/cargo-binstall/pull/2068))

## [0.13.12](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.11...binstalk-downloader-v0.13.12) - 2025-02-11

### Other

- Upgrade hickory-resolver to 0.25.0-alpha.5 ([#2038](https://github.com/cargo-bins/cargo-binstall/pull/2038))

## [0.13.11](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.10...binstalk-downloader-v0.13.11) - 2025-02-04

### Added

- *(downloader)* allow remote::Client to be customised (#2035)

## [0.13.10](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.9...binstalk-downloader-v0.13.10) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [0.13.9](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.8...binstalk-downloader-v0.13.9) - 2025-01-13

### Other

- update Cargo.lock dependencies

## [0.13.8](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.7...binstalk-downloader-v0.13.8) - 2025-01-11

### Other

- *(deps)* bump the deps group with 3 updates (#2015)

## [0.13.7](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.6...binstalk-downloader-v0.13.7) - 2025-01-04

### Other

- *(deps)* bump the deps group with 2 updates (#2010)

## [0.13.6](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.5...binstalk-downloader-v0.13.6) - 2024-12-14

### Other

- *(deps)* bump the deps group with 2 updates (#1997)

## [0.13.5](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.4...binstalk-downloader-v0.13.5) - 2024-11-23

### Other

- *(deps)* bump the deps group with 2 updates ([#1981](https://github.com/cargo-bins/cargo-binstall/pull/1981))

## [0.13.4](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.3...binstalk-downloader-v0.13.4) - 2024-11-09

### Other

- *(deps)* bump the deps group with 3 updates ([#1966](https://github.com/cargo-bins/cargo-binstall/pull/1966))

## [0.13.3](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.2...binstalk-downloader-v0.13.3) - 2024-11-05

### Other

- *(deps)* bump the deps group with 3 updates ([#1954](https://github.com/cargo-bins/cargo-binstall/pull/1954))

## [0.13.2](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.1...binstalk-downloader-v0.13.2) - 2024-11-02

### Other

- Use rc-zip-sync for zip extraction ([#1942](https://github.com/cargo-bins/cargo-binstall/pull/1942))

## [0.13.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.0...binstalk-downloader-v0.13.1) - 2024-08-12

### Other
- Enable happy eyeballs when using hickory-dns ([#1877](https://github.com/cargo-bins/cargo-binstall/pull/1877))

## [0.13.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.12.0...binstalk-downloader-v0.13.0) - 2024-08-10

### Other
- Bump hickory-resolver to 0.25.0-alpha.2 ([#1869](https://github.com/cargo-bins/cargo-binstall/pull/1869))

==> cargo-binstall-1.16.0-1.src.tar.gz: cargo-binstall-1.16.0/crates/binstalk-downloader/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.13.22](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.21...binstalk-downloader-v0.13.22) - 2025-08-30

### Other

- Upgrade compression libraries ([#2289](https://github.com/cargo-bins/cargo-binstall/pull/2289))

## [0.13.21](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.20...binstalk-downloader-v0.13.21) - 2025-07-25

### Other

- *(deps)* bump tokio from 1.46.0 to 1.46.1 in the deps group ([#2222](https://github.com/cargo-bins/cargo-binstall/pull/2222))
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.13.27](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.26...binstalk-downloader-v0.13.27) - 2025-11-15

### Other

- *(deps)* bump bytes from 1.10.1 to 1.11.0 in the deps group ([#2371](https://github.com/cargo-bins/cargo-binstall/pull/2371))

## [0.13.26](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.25...binstalk-downloader-v0.13.26) - 2025-11-09

### Other

- Update rc-zip-sync version to 4.3.5 ([#2362](https://github.com/cargo-bins/cargo-binstall/pull/2362))

## [0.13.25](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.24...binstalk-downloader-v0.13.25) - 2025-10-25

### Fixed

- fix CVE-2025-62518 ([#2340](https://github.com/cargo-bins/cargo-binstall/pull/2340))

### Other

- *(deps)* bump flate2 from 1.1.4 to 1.1.5 in the deps group ([#2342](https://github.com/cargo-bins/cargo-binstall/pull/2342))

## [0.13.24](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.23...binstalk-downloader-v0.13.24) - 2025-10-24

### Other

- *(lints)* introduce typos-cli config in `Cargo.toml` and handle typos ([#2337](https://github.com/cargo-bins/cargo-binstall/pull/2337))
- *(deps)* bump rc-zip-sync from 4.3.1 to 4.3.2 in the deps group ([#2334](https://github.com/cargo-bins/cargo-binstall/pull/2334))

## [0.13.23](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.22...binstalk-downloader-v0.13.23) - 2025-09-14

### Added

- respect socks5 in `https_proxy` ([#2306](https://github.com/cargo-bins/cargo-binstall/pull/2306))

## [0.13.20](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.19...binstalk-downloader-v0.13.20) - 2025-06-06

### Other

- updated the following local packages: binstalk-types

## [0.13.19](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.18...binstalk-downloader-v0.13.19) - 2025-05-30

### Other

- Upgrade reqwest to 0.12.17 ([#2168](https://github.com/cargo-bins/cargo-binstall/pull/2168))

## [0.13.18](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.17...binstalk-downloader-v0.13.18) - 2025-05-16

### Other

- Upgrade transitive dependencies ([#2154](https://github.com/cargo-bins/cargo-binstall/pull/2154))

## [0.13.17](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.16...binstalk-downloader-v0.13.17) - 2025-04-05

### Other

- Fix clippy lints ([#2111](https://github.com/cargo-bins/cargo-binstall/pull/2111))

## [0.13.16](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.15...binstalk-downloader-v0.13.16) - 2025-03-19

### Other

- Fix clippy warnings for detect-targets and binstalk-downloader ([#2098](https://github.com/cargo-bins/cargo-binstall/pull/2098))
- Bump hickory-resolver to 0.25.1 ([#2096](https://github.com/cargo-bins/cargo-binstall/pull/2096))

## [0.13.15](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.14...binstalk-downloader-v0.13.15) - 2025-03-15

### Other

- *(deps)* bump the deps group with 2 updates ([#2084](https://github.com/cargo-bins/cargo-binstall/pull/2084))
- *(deps)* bump tokio from 1.43.0 to 1.44.0 in the deps group ([#2079](https://github.com/cargo-bins/cargo-binstall/pull/2079))

## [0.13.14](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.13...binstalk-downloader-v0.13.14) - 2025-03-07

### Other

- Use bzip2/libbz2-rs-sys ([#2071](https://github.com/cargo-bins/cargo-binstall/pull/2071))
- *(deps)* bump the deps group with 3 updates ([#2072](https://github.com/cargo-bins/cargo-binstall/pull/2072))

## [0.13.13](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.12...binstalk-downloader-v0.13.13) - 2025-02-28

### Other

- Use flate2/zlib-rs for dev/release build ([#2068](https://github.com/cargo-bins/cargo-binstall/pull/2068))

## [0.13.12](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.11...binstalk-downloader-v0.13.12) - 2025-02-11

### Other

- Upgrade hickory-resolver to 0.25.0-alpha.5 ([#2038](https://github.com/cargo-bins/cargo-binstall/pull/2038))

## [0.13.11](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.10...binstalk-downloader-v0.13.11) - 2025-02-04

### Added

- *(downloader)* allow remote::Client to be customised (#2035)

## [0.13.10](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.9...binstalk-downloader-v0.13.10) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [0.13.9](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.8...binstalk-downloader-v0.13.9) - 2025-01-13

### Other

- update Cargo.lock dependencies

## [0.13.8](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.7...binstalk-downloader-v0.13.8) - 2025-01-11

### Other

- *(deps)* bump the deps group with 3 updates (#2015)

## [0.13.7](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.6...binstalk-downloader-v0.13.7) - 2025-01-04

### Other

- *(deps)* bump the deps group with 2 updates (#2010)

## [0.13.6](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.5...binstalk-downloader-v0.13.6) - 2024-12-14

### Other

- *(deps)* bump the deps group with 2 updates (#1997)

## [0.13.5](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.4...binstalk-downloader-v0.13.5) - 2024-11-23

### Other

- *(deps)* bump the deps group with 2 updates ([#1981](https://github.com/cargo-bins/cargo-binstall/pull/1981))

## [0.13.4](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.3...binstalk-downloader-v0.13.4) - 2024-11-09

### Other

- *(deps)* bump the deps group with 3 updates ([#1966](https://github.com/cargo-bins/cargo-binstall/pull/1966))

## [0.13.3](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.2...binstalk-downloader-v0.13.3) - 2024-11-05

### Other

- *(deps)* bump the deps group with 3 updates ([#1954](https://github.com/cargo-bins/cargo-binstall/pull/1954))

## [0.13.2](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.1...binstalk-downloader-v0.13.2) - 2024-11-02

### Other

- Use rc-zip-sync for zip extraction ([#1942](https://github.com/cargo-bins/cargo-binstall/pull/1942))

## [0.13.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.0...binstalk-downloader-v0.13.1) - 2024-08-12

### Other
- Enable happy eyeballs when using hickory-dns ([#1877](https://github.com/cargo-bins/cargo-binstall/pull/1877))

## [0.13.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.12.0...binstalk-downloader-v0.13.0) - 2024-08-10

### Other
- Bump hickory-resolver to 0.25.0-alpha.2 ([#1869](https://github.com/cargo-bins/cargo-binstall/pull/1869))
